@@ -40,14 +40,6 @@ import async_generator
 import async_exit_stack
 
 
-try:
-    import asks
-except ImportError:
-    pass
-else:
-    asks.init("trio")
-
-
 from . import _version
 from . import config
 from . import utils
